package at.ac.uibk.gitsearch.service;

import java.io.DataInput;
import java.io.DataInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;
import java.util.ArrayList;
import java.util.List;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.loader.tools.FileUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.FileCopyUtils;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.dataformat.yaml.YAMLFactory;

import at.ac.uibk.gitsearch.service.dto.SearchInputDTO;
import at.ac.uibk.gitsearch.service.dto.SearchResultsDTO;
import at.ac.uibk.gitsearch.service.dto.SearchResultsDTO.SearchResultDTO;

/**
 * Service for exercise/course search results
 * <p>
 */
@Service
public class SearchService {

	private final Logger log = LoggerFactory.getLogger(SearchService.class);

	public SearchService() {

	}

	/**
	 * returns
	 * 
	 * @param searchInput
	 * @param first
	 * @param length
	 */
	public SearchResultsDTO searchResultPage(SearchInputDTO searchInput, int first, int length) {
		log.debug("Searchrequest for {} ", searchInput);

		return readTestResults();
	}

	/**
	 * temporary static test data
	 * 
	 * @return
	 */
	private SearchResultsDTO readTestResults() {
		ObjectMapper mapper = new ObjectMapper(new YAMLFactory());
		mapper.findAndRegisterModules();

		List<SearchResultDTO> result = new ArrayList<SearchResultsDTO.SearchResultDTO>();

		for (String testFile : new String[] { "metaData1.yaml", "metaData2.yaml" }) {
			log.debug( "reading test data from {} ",  testFile);
			
			final InputStream metaDataStream = this.getClass().getResourceAsStream("testData/" + testFile);
			try {
				byte[] fileContent = FileCopyUtils.copyToByteArray(metaDataStream);
				SearchResultDTO searchResultDTO = mapper.readValue(fileContent, SearchResultDTO.class);
				result.add(searchResultDTO);
			} catch (IOException e) {
				log.error( "Cannot read test search input from " + testFile, e);
			}
		}
		return new SearchResultsDTO(result, result.size());

	}

}
