package at.ac.uibk.gitsearch.service.dto;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonValue;

public class SearchResultsDTO {

	@JsonFormat(shape = JsonFormat.Shape.OBJECT)
	public enum ExerciseType {
		PROGRAMMING_EXERCISE ("programming exercise"),
		EXERCISE("exercise"),
		COLLECTION("collection"),
		OTHER("other");
		
		ExerciseType(String externalName) {
			this.externalName = externalName;
		}
 		private String externalName;
 		
 		@JsonValue
		public String getExternalName() {
			return externalName;
		}
	}
	
	public static class Person {
		private String name;
		private String affiliation;
		private String email;
		
		public String getName() {
			return name;
		}
		public void setName(String name) {
			this.name = name;
		}
		public String getAffiliation() {
			return affiliation;
		}
		public void setAffiliation(String affiliation) {
			this.affiliation = affiliation;
		}
		public String getEmail() {
			return email;
		}
		public void setEmail(String email) {
			this.email = email;
		}
	}
	public static class SearchResultDTO {
		private String metadataVersion; // just for YAML testdata reader 
		private String title;
		private String identifier;
		private String version;
		private String structure;
		
		private String description;
		private ExerciseType type;
		private String license;
		private String[] keyword;
		
		private String format;
		private String[] programmingLanguage;
		private String[] language;
		private String status;
		
		private String educationLevel;
		
		@JsonIgnore
		private String audience;
		
		private String timeRequired;
		
		@JsonIgnore
		private String collectionContent;
		
		public String getTimeRequired() {
			return timeRequired;
		}

		public void setTimeRequired(String timeRequired) {
			this.timeRequired = timeRequired;
		}

		private Person[] creator;
		private Person[] publisher;
		private Person[] contributor;
		
		private boolean deprecated;
		
		private String difficulty;
		private String[] source;
		
		private String requires;
		private String image;
		
		
		
		public String getIdentifier() {
			return identifier;
		}

		public void setIdentifier(String identifier) {
			this.identifier = identifier;
		}

		public String getVersion() {
			return version;
		}

		public void setVersion(String version) {
			this.version = version;
		}

		public ExerciseType getType() {
			return type;
		}

		public void setType(ExerciseType type) {
			this.type = type;
		}

		public String[] getLanguage() {
			return language;
		}

		public void setLanguage(String[] language) {
			this.language = language;
		}

		public String getStatus() {
			return status;
		}

		public void setStatus(String status) {
			this.status = status;
		}

		public String getEducationLevel() {
			return educationLevel;
		}

		public void setEducationLevel(String educationLevel) {
			this.educationLevel = educationLevel;
		}

		public String getAudience() {
			return audience;
		}

		public void setAudience(String audience) {
			this.audience = audience;
		}

		public Person[] getCreator() {
			return creator;
		}

		public void setCreator(Person[] creator) {
			this.creator = creator;
		}

		public Person[] getPublisher() {
			return publisher;
		}

		public void setPublisher(Person[] publisher) {
			this.publisher = publisher;
		}

		public Person[] getContributor() {
			return contributor;
		}

		public void setContributor(Person[] contributor) {
			this.contributor = contributor;
		}

		public boolean isDeprecated() {
			return deprecated;
		}

		public void setDeprecated(boolean deprecated) {
			this.deprecated = deprecated;
		}

		public String getDifficulty() {
			return difficulty;
		}

		public void setDifficulty(String difficulty) {
			this.difficulty = difficulty;
		}

		public String[] getSource() {
			return source;
		}

		public void setSource(String[] source) {
			this.source = source;
		}

		public String getRequires() {
			return requires;
		}

		public void setRequires(String requires) {
			this.requires = requires;
		}

		public String getImage() {
			return image;
		}

		public void setImage(String image) {
			this.image = image;
		}

		private String repositoryURL;

		public String getMetadataVersion() {
			return metadataVersion;
		}

		public void setMetadataVersion(String metadataVersion) {
			this.metadataVersion = metadataVersion;
		}

		public String getTitle() {
			return title;
		}

		public void setTitle(String title) {
			this.title = title;
		}

		public String getDescription() {
			return description;
		}

		public void setDescription(String description) {
			this.description = description;
		}

		public String getLicense() {
			return license;
		}

		public void setLicense(String license) {
			this.license = license;
		}

		public String[] getKeyword() {
			return keyword;
		}

		public void setKeyword(String[] keyword) {
			this.keyword = keyword;
		}

		public String getFormat() {
			return format;
		}

		public void setFormat(String format) {
			this.format = format;
		}

		public String[] getProgrammingLanguage() {
			return programmingLanguage;
		}

		public void setProgrammingLanguage(String[] programmingLanguage) {
			this.programmingLanguage = programmingLanguage;
		}

		public String getRepositoryURL() {
			return repositoryURL;
		}

		public void setRepositoryURL(String repositoryURL) {
			this.repositoryURL = repositoryURL;
		}

		public String getStructure() {
			return structure;
		}

		public void setStructure(String structure) {
			this.structure = structure;
		}
		
		// TODO
	}

	private List<SearchResultDTO> searchResult;

	public List<SearchResultDTO> getSearchResult() {
		return searchResult;
	}

	public void setSearchResult(List<SearchResultDTO> searchResult) {
		this.searchResult = searchResult;
	}

	long hitCount;

	public SearchResultsDTO(List<SearchResultDTO> searchResult, long hitCount) {
		this.searchResult = searchResult;
		this.hitCount = hitCount;
	}

	public SearchResultsDTO() {

	}

	public long getHitCount() {
		return hitCount;
	}

	public void setHitCount(long hitCount) {
		this.hitCount = hitCount;
	}
}
